########
Adapters
########

Adapters are wrappers around resources that allow for an alternate view of the data contained in a resource or provide
additional functionality that is specific to part of your code base. An adapter can be used just like the plain resource
with most methods within Odin, including codecs.

See :doc:`../examples/adapters`
